@@ -13,9 +13,10 @@ class Accounts(Resource):
 
     def _set_urls(self):
 
-        self.urls = {
-            "read": f"/accounts/{super().get_bank_id()}"
-        }
+        if super().get_bank_id() in super().THIRD_PARTY_BANKING.keys():
+            self.urls["read"] = f"/v1/{super().THIRD_PARTY_BANKING.get(super().get_bank_id(),0)}"
+        else:
+            self.urls["read"] = f"/accounts/{super().get_bank_id()}"
 
         super().set_urls(self.urls)
 
@@ -71,6 +72,14 @@ class Accounts(Resource):
             # If bank_id is NCBA
             elif super().get_bank_id() == super().NCBA:
                 pass
+            # If bank_id is THIRD_PARTY_BANKING
+            elif super().get_bank_id() in super().THIRD_PARTY_BANKING.keys():
+                data.update({
+                    "businessCode": payload.get("client_id", "")
+                })
+                data.update({
+                    "accountIds": [payload.get("account_number", "")]
+                })
 
         elif operation == super().FULL_STATEMENT:
             # If bank_id is COOP
@@ -118,7 +127,7 @@ class Accounts(Resource):
                     "AccountNumber": f'{payload.get("account_number", "")}'
                 })
                 data.update({
-                    "NoOfTransactions": f'{payload.get("limit", "")}'
+                    "NoOfTransactions": f'{payload.get("limit", 1)}'
                 })
             # If bank_id is EQUITY
             elif super().get_bank_id() == super().EQUITY:
@@ -127,6 +136,23 @@ class Accounts(Resource):
             # If bank_id is NCBA
             elif super().get_bank_id() == super().NCBA:
                 pass
+            # If bank_id is THIRD_PARTY_BANKING
+            elif super().get_bank_id() in super().THIRD_PARTY_BANKING.keys():
+                data.update({
+                    "businessCode": payload.get("client_id", "")
+                })
+                data.update({
+                    "accountIds": [payload.get("account_number", "")]
+                })
+                data.update({
+                    "limit": payload.get("limit", 1)
+                })
+                data.update({
+                    "startDate": payload.get("start_date", "")
+                })
+                data.update({
+                    "endDate": payload.get("end_date", "")
+                })
 
         data.update(payload.get("additional_properties", {}))
 
