@@ -2,6 +2,7 @@ from bank_sync.Resources.resource import Resource
 from bank_sync.APIs.utils.generate_code import get_code
 from datetime import date
 
+
 class Payments(Resource):
 
     urls = {}
@@ -12,9 +13,10 @@ class Payments(Resource):
 
     def _set_urls(self):
 
-        self.urls = {
-            "read": f"/payment/{super().get_bank_id()}"
-        }
+        if super().get_bank_id() in super().THIRD_PARTY_BANKING.keys():
+            self.urls["read"] = f"/v1/{super().THIRD_PARTY_BANKING.get(super().get_bank_id(),0)}"
+        else:
+            self.urls["read"] = f"/payment/{super().get_bank_id()}"
 
         super().set_urls(self.urls)
 
@@ -52,6 +54,11 @@ class Payments(Resource):
 
         return super().read(payload=payload, endpoint=f'{self.urls["read"]}{endpoint}')
 
+    # API Endpoint used by third party integrations
+    def initiate_payment(self, payload=None, endpoint='/initiate_payment'):
+
+        return super().read(payload=payload, endpoint=f'{self.urls["read"]}{endpoint}')
+
     def serialize(self, payload=None, operation=None):
 
         super().set_operation(operation)
@@ -366,7 +373,7 @@ class Payments(Resource):
             # If bank_id is COOP
             if super().get_bank_id() == super().COOP:
                 pass
-            elif super().get_bank_id() == super().EQUITY:                
+            elif super().get_bank_id() == super().EQUITY:
                 pass
             # If bank_id is NCBA
             elif super().get_bank_id() == super().NCBA:
@@ -584,6 +591,33 @@ class Payments(Resource):
                     "reference_number": payload.get("reference", None),
                     "country": payload.get("country", None)
                 })
+        elif operation == super().INITIATE_PAYMENT:
+
+            if super().get_bank_id() in super().THIRD_PARTY_BANKING.keys():
+                destinations = payload.get("destinations", [])
+                if len(destinations) > 0:
+                    destination = destinations[0]
+
+                    data = {
+                        "secret": payload.get("transfer", {}).get("secret", ""),
+                        "clientId": payload.get("transfer", {}).get("client_id", ""),
+                        "receiptName": destination.get("name", ""),
+                        "targetAccount": destination.get("account_number", ""),
+                        "sortCode": payload.get("transfer", {}).get("sort_code", ""),
+                        "currency": payload.get("transfer", {}).get("currency_code", ""),
+                        "value": destination.get("amount", 0),
+                        "referenceID": payload.get("transfer", {}).get("reference", ""),
+                        # "referenceMetaData": "string",
+                        "type":  payload.get("type", {}).get("sort_code", ""),
+                        "description": payload.get("transfer", {}).get("description", ""),
+                        # "nickname": "string",
+                        "country": payload.get("transfer", {}).get("country", ""),
+                        "branchAddress": payload.get("transfer", {}).get("branch_address", ""),
+                        "branchName": payload.get("transfer", {}).get("branch_name", ""),
+                        "swiftCode": payload.get("transfer", {}).get("bank_swift_code", ""),
+                        "iban": payload.get("transfer", {}).get("iban", ""),
+                        "bankName": payload.get("transfer", {}).get("bank_name", ""),
+                    }
 
         data.update(payload.get("additional_properties", {}))
 
@@ -594,20 +628,22 @@ class Payments(Resource):
         data = {}
 
         response_data = super().response()
-        data["payload"] = response_data.get("payload", {})
 
         if super().get_bank_id() == super().COOP:
 
             data["message"] = response_data.get("MessageDescription", "")
             data["code"] = int(response_data.get("MessageCode", -1111111))
-            data["date"] = response_data.get("MessageDateTime", date.today().strttime('%d/%m/%y %H:%M:%S'))
-            data["transaction_id"] = response_data.get("Destinations", {}).get("TransactionID", "")
+            data["date"] = response_data.get(
+                "MessageDateTime", date.today().strttime('%d/%m/%y %H:%M:%S'))
+            data["transaction_id"] = response_data.get(
+                "Destinations", {}).get("TransactionID", "")
 
             if 'MessageDescription' in response_data.keys():
                 if response_data.get("MessageDescription", "") == "Full Success":
                     data["message"] = "success"
                 else:
-                    data["message"] = response_data.get("MessageDescription", "")
+                    data["message"] = response_data.get(
+                        "MessageDescription", "")
 
             if 'MessageCode' in response_data.keys():
                 data["code"] = int(response_data.get("MessageCode", -1111111))
@@ -616,7 +652,8 @@ class Payments(Resource):
                 if response_data.get("messageDescription", "") == "Full Success":
                     data["message"] = "success"
                 else:
-                    data["message"] = response_data.get("messageDescription", "")
+                    data["message"] = response_data.get(
+                        "messageDescription", "")
 
             if 'messageCode' in response_data.keys():
                 data["code"] = response_data.get("messageCode", -1111111)
@@ -624,11 +661,12 @@ class Payments(Resource):
         elif super().get_bank_id() == super().EQUITY:
             data["message"] = response_data.get("message", "")
             data["code"] = response_data.get("code", -1111111)
-            data["transaction_id"] = response_data.get("data", {}).get("transactionId", "")
-            data["date"] = response_data.get("date", date.today().strftime('%d/%m/%y %H:%M:%S'))
-            
-            
+            data["transaction_id"] = response_data.get(
+                "data", {}).get("transactionId", "")
+            data["date"] = response_data.get(
+                "date", date.today().strftime('%d/%m/%y %H:%M:%S'))
+
         if bool(data):
             return data
 
-        return super().response()
\ No newline at end of file
+        return super().response()
